@@ -31,7 +31,8 @@ class _ManagedContainer( PartialContainer ):
         
     def setConstraintManager( self, constraints ):
         self.constraints = constraints
-        self.setQueryModifier( constraints.getQueryModifier( self.__parent__, self ) )
+        if self.__parent__ is not None:
+            self.setQueryModifier( constraints.getQueryModifier( self.__parent__, self ) )
 
 class ConstraintManager( object ):
     """
@@ -116,9 +117,8 @@ class ManagedContainerDescriptor(object):
         container = self.domain_container()
         if instance is None:
             return container
-        if ILocation.providedBy( instance ):
-            container.__parent__ = instance
-            container.__name__ = self.name
+        container.__parent__ = instance
+        container.__name__ = self.name
         container.setConstraintManager( self.constraint )
         return container
     
